==> scanbot_sdk-2.13.0-alpha01.tar.gz: lib/barcode_scanning_data.dart <==
import 'dart:typed_data';

import 'package:json_annotation/json_annotation.dart';
import 'barcode_parsers/barcode_scanner.dart';
import 'json/barcode_configuration_json.dart';
import 'json/batch_barcode_configuration_json.dart';
import 'json/common.dart';
import 'sdk_utils.dart';

import 'json/common_platform.dart';

export 'json/barcode_configuration_json.dart';
export 'barcode_parsers/aamva.dart';
export 'barcode_parsers/barcode_scanner.dart';
export 'barcode_parsers/boarding_pass.dart';
export 'barcode_parsers/de_medical_plan.dart';
export 'barcode_parsers/id_card_pdf_417.dart';
export 'barcode_parsers/medical_certificate.dart';
export 'barcode_parsers/sepa.dart';
export 'barcode_parsers/vcard.dart';

part 'barcode_scanning_data.g.dart';

@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class BarcodeScanningResult extends Result {
  List<BarcodeItem> barcodeItems = <BarcodeItem>[];

  Uri? barcodeImageURI;

  BarcodeScanningResult(this.barcodeItems);

  /// We can use this method named constructor while detection of Multiple images
  BarcodeScanningResult.fromUrlAndCode(this.barcodeImageURI, this.barcodeItems);

  BarcodeScanningResult.error(String message) {
    operationResult = OperationResult.ERROR;
    this.message = message;
  }

  BarcodeScanningResult.canceled() {
    operationResult = OperationResult.CANCELED;
  }

  factory BarcodeScanningResult.fromJson(Map<String, dynamic> json) =>
      _$BarcodeScanningResultFromJson(json);

  Map<String, dynamic> toJson() => _$BarcodeScanningResultToJson(this);
}

///Class created for handling the multiple images barcodes detection
@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class MultiImageBarcodeScanningResult extends Result {
  List<BarcodeScanningResult> barcodeResults = <BarcodeScanningResult>[];

  MultiImageBarcodeScanningResult(this.barcodeResults);

  MultiImageBarcodeScanningResult.error(String message) {
    operationResult = OperationResult.ERROR;
    this.message = message;
  }

  MultiImageBarcodeScanningResult.canceled() {
    operationResult = OperationResult.CANCELED;
  }

  factory MultiImageBarcodeScanningResult.fromJson(Map<String, dynamic> json) =>
      _$MultiImageBarcodeScanningResultFromJson(json);

  Map<String, dynamic> toJson() =>
      _$MultiImageBarcodeScanningResultToJson(this);
}

@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class BarcodeItem {
  BarcodeFormattedResult? formattedResult;

  ///Scanned barcode format
  BarcodeFormat? barcodeFormat;

  ///Result data from barcode
  String? text;

  @JsonKey(fromJson: uintListFromString)

  ///raw data of barcode
  Uint8List? rawBytes;

  BarcodeItem(this.barcodeFormat, this.text);

  factory BarcodeItem.fromJson(Map<String, dynamic> json) =>
      _$BarcodeItemFromJson(json);

  Map<String, dynamic> toJson() => _$BarcodeItemToJson(this);
}

class PredefinedBarcodes {
  ///return list of one dimensional barcode formats
  static List<BarcodeFormat> allBarcodeTypes() {
    return [
      BarcodeFormat.AZTEC,
      BarcodeFormat.CODABAR,
      BarcodeFormat.CODE_39,
      BarcodeFormat.CODE_93,
      BarcodeFormat.CODE_128,
      BarcodeFormat.DATA_MATRIX,
      BarcodeFormat.EAN_8,
      BarcodeFormat.EAN_13,
      BarcodeFormat.ITF,
      BarcodeFormat.PDF_417,
      BarcodeFormat.QR_CODE,
      BarcodeFormat.RSS_14,
      BarcodeFormat.RSS_EXPANDED,
      BarcodeFormat.UPC_A,
      BarcodeFormat.UPC_E,
      BarcodeFormat.MSI_PLESSEY,
      BarcodeFormat.IATA_2_OF_5,
      BarcodeFormat.INDUSTRIAL_2_OF_5,
      BarcodeFormat.CODE_25
    ];
  }

  static List<BarcodeDocumentFormat> allDocumentFormatTypes() {
    return [
      BarcodeDocumentFormat.AAMVA,
      BarcodeDocumentFormat.BOARDING_PASS,
      BarcodeDocumentFormat.DE_MEDICAL_PLAN,
      BarcodeDocumentFormat.MEDICAL_CERTIFICATE,
      BarcodeDocumentFormat.ID_CARD_PDF_417,
      BarcodeDocumentFormat.SEPA,
      BarcodeDocumentFormat.SWISS_QR,
      BarcodeDocumentFormat.VCARD
    ];
  }

  static List<BarcodeFormat> oneDimensionalBarcodes() {
    return [
      BarcodeFormat.CODABAR,
      BarcodeFormat.CODE_128,
      BarcodeFormat.CODE_39,
      BarcodeFormat.CODE_93,
      BarcodeFormat.EAN_13,
      BarcodeFormat.EAN_8,
      BarcodeFormat.ITF,
      BarcodeFormat.UPC_A,
      BarcodeFormat.RSS_14,
      BarcodeFormat.RSS_EXPANDED,
      BarcodeFormat.UPC_E,
      BarcodeFormat.MSI_PLESSEY,
      BarcodeFormat.IATA_2_OF_5,
      BarcodeFormat.INDUSTRIAL_2_OF_5,
      BarcodeFormat.CODE_25
    ];
  }

  ///return list of two dimensional barcode formats
  static List<BarcodeFormat> twoDimensionalBarcodes() {
    return [
      BarcodeFormat.AZTEC,
      BarcodeFormat.DATA_MATRIX,
      BarcodeFormat.PDF_417,
      BarcodeFormat.QR_CODE
    ];
  }
}

class BarcodeScannerConfiguration extends BarcodeScannerJsonConfiguration {
  ///The configuration object should be applied for this screen
  @override
  String? screen = "BarcodeScanner";

  /// Additional parameters for tweaking the detection of barcodes.
  BarcodeAdditionalParameters? additionalParameters;

  BarcodeScannerConfiguration(
      {super.acceptedDocumentFormats,
      super.cameraOverlayColor,
      super.cameraModule,
      super.cameraZoomFactor,
      super.cancelButtonHidden,
      super.cancelButtonTitle,
      super.engineMode,
      super.enableCameraButtonTitle,
      super.enableCameraExplanationText,
      super.finderLineColor,
      super.finderLineWidth,
      super.finderTextHint,
      super.finderTextHintColor,
      super.finderAspectRatio,
      super.flashButtonHidden,
      super.flashButtonTitle,
      super.flashButtonInactiveColor,
      super.flashEnabled,
      super.focusLockEnabled,
      super.focusLockPosition,
      super.orientationLockMode,
      super.minimumTextLength,
      super.maximumTextLength,
      super.minFocusDistanceLock,
      super.minimum1DBarcodesQuietZone,
      super.stripCheckDigits,
      super.successBeepEnabled,
      super.topBarBackgroundColor,
      super.topBarButtonsColor,
      super.barcodeFormats,
      super.useButtonsAllCaps,
      super.replaceCancelButtonWithIcon,
      super.cameraPreviewMode,
      super.cameraZoomRange,
      super.autoCancelTimeout,
      super.gs1DecodingEnabled,
      super.msiPlesseyChecksumAlgorithm,
      super.lowPowerMode,
      super.codeDensity,
      super.barcodeImageGenerationType,
      super.initialScanDelay,
      super.delayAfterScan,
      super.doubleTapToZoomEnabled,
      super.pinchToZoomEnabled,
      super.shouldAnimateZooming,
      super.viewFinderEnabled,
      super.confirmationDialogConfiguration,
      super.overlayConfiguration,
      this.additionalParameters}) {
    if (additionalParameters != null) {
      minimumTextLength =
          minimumTextLength ?? additionalParameters?.minimumTextLength;
      maximumTextLength =
          maximumTextLength ?? additionalParameters?.maximumTextLength;
      minimum1DBarcodesQuietZone = minimum1DBarcodesQuietZone ??
          additionalParameters?.minimum1DBarcodesQuietZone;
      gs1DecodingEnabled =
          gs1DecodingEnabled ?? additionalParameters?.enableGS1Decoding;
      msiPlesseyChecksumAlgorithm = msiPlesseyChecksumAlgorithm ??
          additionalParameters?.msiPlesseyChecksumAlgorithm;
      stripCheckDigits =
          stripCheckDigits ?? additionalParameters?.stripCheckDigits;
    }
  }
}

@JsonSerializable(includeIfNull: false, explicitToJson: true)
class DetectBarcodeFromImageParams {
  ///file or content uri
  Uri? uri;

  /// list of multiple file or content uri
  List<Uri>? uris;

  /// Barcode formats which need to be recognized.
  List<BarcodeFormat> barcodeFormats = <BarcodeFormat>[];

  /// Barcode document formats which need to be recognized.
  List<BarcodeDocumentFormat> acceptedDocumentFormats =
      <BarcodeDocumentFormat>[];

  DetectBarcodeFromImageParams(
    this.uri,
    this.barcodeFormats,
    this.acceptedDocumentFormats,
  );

  /// constructor overloading is acheived by giving it a name
  /// Below consturctor is used for multiple images
  DetectBarcodeFromImageParams.fromMultiple(
    this.uris,
    this.barcodeFormats,
    this.acceptedDocumentFormats,
  );

  factory DetectBarcodeFromImageParams.fromJson(Map<String, dynamic> json) =>
      _$DetectBarcodeFromImageParamsFromJson(json);

  Map<String, dynamic> toJson() => _$DetectBarcodeFromImageParamsToJson(this);
}

@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class BarcodeFormattedData {
  String? title;
  String? subtitle;

  BarcodeFormattedData({this.title, this.subtitle});

  factory BarcodeFormattedData.fromJson(Map<String, dynamic> json) =>
      _$BarcodeFormattedDataFromJson(json);

  Map<String, dynamic> toJson() => _$BarcodeFormattedDataToJson(this);
}

typedef BarcodeDataFormatter = Future<BarcodeFormattedData> Function(
    BarcodeItem barcodeItem);

class BatchBarcodeScannerConfiguration
    extends BatchBarcodeScannerJsonConfiguration {
  ///The configuration object should be applied for this screen
  @override
  String? screen = "BatchBarcodeScanner";

  /// Additional parameters for tweaking the detection of barcodes.
  BarcodeAdditionalParameters? additionalParameters;

  /// Change data representation for scanned list items
  BarcodeDataFormatter? barcodeFormatter;

  BatchBarcodeScannerConfiguration(
      {super.acceptedDocumentFormats,
      super.cameraOverlayColor,
      super.cameraModule,
      super.cameraZoomFactor,
      super.cameraZoomRange,
      super.cancelButtonHidden,
      super.cancelButtonTitle,
      super.doubleTapToZoomEnabled,
      super.pinchToZoomEnabled,
      super.shouldAnimateZooming,
      super.engineMode,
      super.finderLineColor,
      super.finderLineWidth,
      super.finderTextHint,
      super.finderTextHintColor,
      super.finderAspectRatio,
      super.flashButtonHidden,
      super.flashButtonTitle,
      super.flashEnabled,
      super.focusLockEnabled,
      super.focusLockPosition,
      super.orientationLockMode,
      super.minimumTextLength,
      super.maximumTextLength,
      super.minimum1DBarcodesQuietZone,
      super.minFocusDistanceLock,
      super.stripCheckDigits,
      super.successBeepEnabled,
      super.topBarBackgroundColor,
      super.topBarButtonsColor,
      super.topBarButtonsInactiveColor,
      super.barcodeFormats,
      super.useButtonsAllCaps,
      super.gs1DecodingEnabled,
      super.msiPlesseyChecksumAlgorithm,
      super.lowPowerMode,
      super.barcodesCountText,
      super.barcodesCountTextColor,
      super.clearButtonTitle,
      super.detailsActionColor,
      super.detailsBackgroundColor,
      super.detailsPrimaryColor,
      super.deleteButtonTitle,
      super.enableCameraButtonTitle,
      super.enableCameraExplanationText,
      super.fetchingStateText,
      super.noBarcodesTitle,
      super.submitButtonTitle,
      super.codeDensity,
      super.replaceCancelButtonWithIcon,
      super.cameraPreviewMode,
      super.autoCancelTimeout,
      super.initialScanDelay,
      super.viewFinderEnabled,
      super.overlayConfiguration,
      this.additionalParameters,
      this.barcodeFormatter}) {
    if (additionalParameters != null) {
      minimumTextLength =
          minimumTextLength ?? additionalParameters?.minimumTextLength;
      maximumTextLength =
          maximumTextLength ?? additionalParameters?.maximumTextLength;
      minimum1DBarcodesQuietZone = minimum1DBarcodesQuietZone ??
          additionalParameters?.minimum1DBarcodesQuietZone;
      gs1DecodingEnabled =
          gs1DecodingEnabled ?? additionalParameters?.enableGS1Decoding;
      msiPlesseyChecksumAlgorithm = msiPlesseyChecksumAlgorithm ??
          additionalParameters?.msiPlesseyChecksumAlgorithm;
      stripCheckDigits =
          stripCheckDigits ?? additionalParameters?.stripCheckDigits;
    }
  }
}

==> scanbot_sdk-4.2.1-alpha01.tar.gz: lib/barcode_scanning_data.dart <==
import 'dart:typed_data';

import 'package:json_annotation/json_annotation.dart';
import 'barcode_parsers/barcode_scanner.dart';
import 'json/barcode_configuration_json.dart';
import 'json/batch_barcode_configuration_json.dart';
import 'json/common.dart';
import 'sdk_utils.dart';

import 'json/common_platform.dart';

export 'json/common_platform.dart';

export 'json/barcode_configuration_json.dart';
export 'json/batch_barcode_configuration_json.dart';
export 'barcode_parsers/aamva.dart';
export 'barcode_parsers/barcode_scanner.dart';
export 'barcode_parsers/boarding_pass.dart';
export 'barcode_parsers/de_medical_plan.dart';
export 'barcode_parsers/id_card_pdf_417.dart';
export 'barcode_parsers/medical_certificate.dart';
export 'barcode_parsers/sepa.dart';
export 'barcode_parsers/vcard.dart';

part 'barcode_scanning_data.g.dart';

@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class BarcodeScanningResult extends Result {
  List<BarcodeItem> barcodeItems = <BarcodeItem>[];

  Uri? barcodeImageURI;

  BarcodeScanningResult(this.barcodeItems);

  /// We can use this method named constructor while detection of Multiple images
  BarcodeScanningResult.fromUrlAndCode(this.barcodeImageURI, this.barcodeItems);

  BarcodeScanningResult.error(String message) {
    operationResult = OperationResult.ERROR;
    this.message = message;
  }

  BarcodeScanningResult.canceled() {
    operationResult = OperationResult.CANCELED;
  }

  factory BarcodeScanningResult.fromJson(Map<String, dynamic> json) =>
      _$BarcodeScanningResultFromJson(json);

  Map<String, dynamic> toJson() => _$BarcodeScanningResultToJson(this);
}

///Class created for handling the multiple images barcodes detection
@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class MultiImageBarcodeScanningResult extends Result {
  List<BarcodeScanningResult> barcodeResults = <BarcodeScanningResult>[];

  MultiImageBarcodeScanningResult(this.barcodeResults);

  MultiImageBarcodeScanningResult.error(String message) {
    operationResult = OperationResult.ERROR;
    this.message = message;
  }

  MultiImageBarcodeScanningResult.canceled() {
    operationResult = OperationResult.CANCELED;
  }

  factory MultiImageBarcodeScanningResult.fromJson(Map<String, dynamic> json) =>
      _$MultiImageBarcodeScanningResultFromJson(json);

  Map<String, dynamic> toJson() =>
      _$MultiImageBarcodeScanningResultToJson(this);
}

@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class BarcodeItem {
  BarcodeFormattedResult? formattedResult;

  /// Scanned barcode format
  BarcodeFormat? barcodeFormat;

  /// Result data from barcode
  String? text;

  @JsonKey(fromJson: uintListFromString)

  /// Raw data of barcode
  Uint8List? rawBytes;

  BarcodeItem(this.barcodeFormat, this.text);

  factory BarcodeItem.fromJson(Map<String, dynamic> json) =>
      _$BarcodeItemFromJson(json);

  Map<String, dynamic> toJson() => _$BarcodeItemToJson(this);
}

class PredefinedBarcodes {
  /// Return list of one dimensional barcode formats
  static List<BarcodeFormat> allBarcodeTypes() {
    return [
      BarcodeFormat.AZTEC,
      BarcodeFormat.CODABAR,
      BarcodeFormat.CODE_39,
      BarcodeFormat.CODE_93,
      BarcodeFormat.CODE_128,
      BarcodeFormat.DATA_MATRIX,
      BarcodeFormat.EAN_8,
      BarcodeFormat.EAN_13,
      BarcodeFormat.ITF,
      BarcodeFormat.PDF_417,
      BarcodeFormat.QR_CODE,
      BarcodeFormat.RSS_14,
      BarcodeFormat.RSS_EXPANDED,
      BarcodeFormat.UPC_A,
      BarcodeFormat.UPC_E,
      BarcodeFormat.MSI_PLESSEY,
      BarcodeFormat.IATA_2_OF_5,
      BarcodeFormat.INDUSTRIAL_2_OF_5,
      BarcodeFormat.CODE_25,
      BarcodeFormat.MICRO_QR_CODE,
      BarcodeFormat.USPS_INTELLIGENT_MAIL,
      BarcodeFormat.ROYAL_MAIL,
      BarcodeFormat.JAPAN_POST,
      BarcodeFormat.ROYAL_TNT_POST,
      BarcodeFormat.AUSTRALIA_POST,
      BarcodeFormat.DATABAR_LIMITED
    ];
  }

  static List<BarcodeDocumentFormat> allDocumentFormatTypes() {
    return [
      BarcodeDocumentFormat.AAMVA,
      BarcodeDocumentFormat.BOARDING_PASS,
      BarcodeDocumentFormat.DE_MEDICAL_PLAN,
      BarcodeDocumentFormat.MEDICAL_CERTIFICATE,
      BarcodeDocumentFormat.ID_CARD_PDF_417,
      BarcodeDocumentFormat.SEPA,
      BarcodeDocumentFormat.SWISS_QR,
      BarcodeDocumentFormat.VCARD,
      BarcodeDocumentFormat.GS1
    ];
  }

  static List<BarcodeFormat> oneDimensionalBarcodes() {
    return [
      BarcodeFormat.CODABAR,
      BarcodeFormat.CODE_128,
      BarcodeFormat.CODE_39,
      BarcodeFormat.CODE_93,
      BarcodeFormat.EAN_13,
      BarcodeFormat.EAN_8,
      BarcodeFormat.ITF,
      BarcodeFormat.UPC_A,
      BarcodeFormat.RSS_14,
      BarcodeFormat.RSS_EXPANDED,
      BarcodeFormat.UPC_E,
      BarcodeFormat.MSI_PLESSEY,
      BarcodeFormat.IATA_2_OF_5,
      BarcodeFormat.INDUSTRIAL_2_OF_5,
      BarcodeFormat.CODE_25,
      BarcodeFormat.USPS_INTELLIGENT_MAIL,
      BarcodeFormat.ROYAL_MAIL,
      BarcodeFormat.JAPAN_POST,
      BarcodeFormat.ROYAL_TNT_POST,
      BarcodeFormat.AUSTRALIA_POST,
      BarcodeFormat.DATABAR_LIMITED,
    ];
  }

  /// Return list of two dimensional barcode formats
  static List<BarcodeFormat> twoDimensionalBarcodes() {
    return [
      BarcodeFormat.AZTEC,
      BarcodeFormat.DATA_MATRIX,
      BarcodeFormat.PDF_417,
      BarcodeFormat.QR_CODE,
      BarcodeFormat.MICRO_QR_CODE,
    ];
  }
}

class BarcodeScannerConfiguration extends BarcodeScannerJsonConfiguration {
  /// The configuration object should be applied for this screen
  @override
  String? screen = "BarcodeScanner";

  /// Additional parameters for tweaking the detection of barcodes.
  BarcodeAdditionalParameters? additionalParameters;

  BarcodeScannerConfiguration(
      {super.acceptedDocumentFormats,
      super.cameraOverlayColor,
      super.cameraModule,
      super.cameraZoomFactor,
      super.cancelButtonHidden,
      super.cancelButtonTitle,
      super.engineMode,
      super.enableCameraButtonTitle,
      super.enableCameraExplanationText,
      super.finderLineColor,
      super.finderLineWidth,
      super.finderTextHint,
      super.finderTextHintColor,
      super.finderAspectRatio,
      super.flashButtonHidden,
      super.flashButtonTitle,
      super.flashButtonInactiveColor,
      super.flashEnabled,
      super.focusLockEnabled,
      super.focusLockPosition,
      super.orientationLockMode,
      super.minimumTextLength,
      super.maximumTextLength,
      super.minFocusDistanceLock,
      super.minimum1DBarcodesQuietZone,
      super.stripCheckDigits,
      super.successBeepEnabled,
      super.topBarBackgroundColor,
      super.topBarButtonsColor,
      super.barcodeFormats,
      super.useButtonsAllCaps,
      super.replaceCancelButtonWithIcon,
      super.cameraPreviewMode,
      super.cameraZoomRange,
      super.autoCancelTimeout,
      super.gs1HandlingMode,
      super.msiPlesseyChecksumAlgorithm,
      super.lowPowerMode,
      super.codeDensity,
      super.barcodeImageGenerationType,
      super.initialScanDelay,
      super.delayAfterScan,
      super.doubleTapToZoomEnabled,
      super.pinchToZoomEnabled,
      super.shouldAnimateZooming,
      super.viewFinderEnabled,
      super.confirmationDialogConfiguration,
      super.overlayConfiguration,
      super.touchToFocusEnabled,
      super.barcodesExtensionFilter,
      this.additionalParameters}) {
    if (additionalParameters != null) {
      minimumTextLength =
          minimumTextLength ?? additionalParameters?.minimumTextLength;
      maximumTextLength =
          maximumTextLength ?? additionalParameters?.maximumTextLength;
      minimum1DBarcodesQuietZone = minimum1DBarcodesQuietZone ??
          additionalParameters?.minimum1DBarcodesQuietZone;
      gs1HandlingMode =
          gs1HandlingMode ?? additionalParameters?.gs1HandlingMode;
      msiPlesseyChecksumAlgorithm = msiPlesseyChecksumAlgorithm ??
          additionalParameters?.msiPlesseyChecksumAlgorithm;
      stripCheckDigits =
          stripCheckDigits ?? additionalParameters?.stripCheckDigits;
    }
  }
}

@JsonSerializable(includeIfNull: false, explicitToJson: true)
class DetectBarcodeFromImageParams {
  /// File or content uri
  Uri? uri;

  /// List of multiple file or content uri
  List<Uri>? uris;

  /// Barcode formats which need to be recognized.
  List<BarcodeFormat> barcodeFormats = <BarcodeFormat>[];

  /// Barcode document formats which need to be recognized.
  List<BarcodeDocumentFormat> acceptedDocumentFormats =
      <BarcodeDocumentFormat>[];

  DetectBarcodeFromImageParams(
    this.uri,
    this.barcodeFormats,
    this.acceptedDocumentFormats,
  );

  /// constructor overloading is acheived by giving it a name
  /// Below consturctor is used for multiple images
  DetectBarcodeFromImageParams.fromMultiple(
    this.uris,
    this.barcodeFormats,
    this.acceptedDocumentFormats,
  );

  factory DetectBarcodeFromImageParams.fromJson(Map<String, dynamic> json) =>
      _$DetectBarcodeFromImageParamsFromJson(json);

  Map<String, dynamic> toJson() => _$DetectBarcodeFromImageParamsToJson(this);
}

@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class BarcodeFormattedData {
  String? title;
  String? subtitle;

  BarcodeFormattedData({this.title, this.subtitle});

  factory BarcodeFormattedData.fromJson(Map<String, dynamic> json) =>
      _$BarcodeFormattedDataFromJson(json);

  Map<String, dynamic> toJson() => _$BarcodeFormattedDataToJson(this);
}

typedef BarcodeDataFormatter = Future<BarcodeFormattedData> Function(
    BarcodeItem barcodeItem);

class BatchBarcodeScannerConfiguration
    extends BatchBarcodeScannerJsonConfiguration {
  /// The configuration object should be applied for this screen
  @override
  String? screen = "BatchBarcodeScanner";

  /// Additional parameters for tweaking the detection of barcodes.
  BarcodeAdditionalParameters? additionalParameters;

  /// Change data representation for scanned list items
  BarcodeDataFormatter? barcodeFormatter;

  BatchBarcodeScannerConfiguration(
      {super.acceptedDocumentFormats,
      super.cameraOverlayColor,
      super.cameraModule,
      super.cameraZoomFactor,
      super.cameraZoomRange,
      super.cancelButtonHidden,
      super.cancelButtonTitle,
      super.doubleTapToZoomEnabled,
      super.pinchToZoomEnabled,
      super.shouldAnimateZooming,
      super.engineMode,
      super.finderLineColor,
      super.finderLineWidth,
      super.finderTextHint,
      super.finderTextHintColor,
      super.finderAspectRatio,
      super.flashButtonHidden,
      super.flashButtonTitle,
      super.flashEnabled,
      super.focusLockEnabled,
      super.focusLockPosition,
      super.orientationLockMode,
      super.minimumTextLength,
      super.maximumTextLength,
      super.minimum1DBarcodesQuietZone,
      super.minFocusDistanceLock,
      super.stripCheckDigits,
      super.successBeepEnabled,
      super.topBarBackgroundColor,
      super.topBarButtonsColor,
      super.topBarButtonsInactiveColor,
      super.barcodeFormats,
      super.useButtonsAllCaps,
      super.gs1HandlingMode,
      super.msiPlesseyChecksumAlgorithm,
      super.lowPowerMode,
      super.barcodesCountText,
      super.barcodesCountTextColor,
      super.clearButtonTitle,
      super.detailsActionColor,
      super.detailsBackgroundColor,
      super.detailsPrimaryColor,
      super.deleteButtonTitle,
      super.enableCameraButtonTitle,
      super.enableCameraExplanationText,
      super.fetchingStateText,
      super.noBarcodesTitle,
      super.submitButtonTitle,
      super.codeDensity,
      super.replaceCancelButtonWithIcon,
      super.cameraPreviewMode,
      super.autoCancelTimeout,
      super.initialScanDelay,
      super.viewFinderEnabled,
      super.overlayConfiguration,
      super.touchToFocusEnabled,
      super.barcodesExtensionFilter,
      this.additionalParameters,
      this.barcodeFormatter}) {
    if (additionalParameters != null) {
      minimumTextLength =
          minimumTextLength ?? additionalParameters?.minimumTextLength;
      maximumTextLength =
          maximumTextLength ?? additionalParameters?.maximumTextLength;
      minimum1DBarcodesQuietZone = minimum1DBarcodesQuietZone ??
          additionalParameters?.minimum1DBarcodesQuietZone;
      gs1HandlingMode =
          gs1HandlingMode ?? additionalParameters?.gs1HandlingMode;
      msiPlesseyChecksumAlgorithm = msiPlesseyChecksumAlgorithm ??
          additionalParameters?.msiPlesseyChecksumAlgorithm;
      stripCheckDigits =
          stripCheckDigits ?? additionalParameters?.stripCheckDigits;
    }
  }
}
